#ifndef _LINUX_APM_H
#define _LINUX_APM_H

/*
 * Include file for the interface to an APM BIOS
 * by Stephen Rothwell
 *    sfr@pdact.pd.necisa.oz.au
 *
 * $Id: apm_bios.h,v 0.3 1994/09/02 01:17:00 sfr Exp $
 */

#ifdef __KERNEL__

#include <linux/tasks.h>	/* for NR_TASKS */
#include <linux/sched.h>	/* for _TSS */

#define APM_CS		_TSS(NR_TASKS)
#define APM_CS_16	(APM_CS + 8)
#define APM_DS		(APM_CS_16 + 8)

struct apm_bios_info {
	unsigned short	version;
	unsigned short	cseg;
	unsigned long	offset;
	unsigned short	cseg_16;
	unsigned short	dseg;
	unsigned short	flags;
	unsigned short	cseg_len;
	unsigned short	dseg_len;
};

#define APM_16_BIT_SUPPORT	0x0001
#define APM_32_BIT_SUPPORT	0x0002
#define APM_IDLE_SLOWS_CLOCK	0x0004
#define APM_DISABLED		0x0008

/*
 * in init/main.c
 */
extern struct apm_bios_info		apm_bios_info;

extern long		apm_bios_init(long);

#endif	/* __KERNEL__ */

typedef unsigned short			apm_event_t;

/*
 * Events
 */
#define APM_SYS_STANDBY			0x0001
#define APM_SYS_SUSPEND			0x0002
#define APM_NORMAL_RESUME		0x0003
#define APM_CRITICAL_RESUME		0x0004
#define APM_LOW_BATTERY			0x0005
#define APM_POWER_STATUS_CHANGE		0x0006
#define APM_UPDATE_TIME			0x0007
#define APM_CRITICAL_SUSPEND		0x0008
#define APM_USER_STANDBY		0x0009
#define APM_USER_SUSPEND		0x000a
#define APM_SYS_STANDBY_RESUME		0x000b

#endif	/* LINUX_APM_H */
